import React, { Component } from 'react';
import PropTypes from 'prop-types';

import RowCell from './RowCell';
import '../.././datagrid.css';
/*
* The Row component for the grid which will render - RenderRow.
* @type {class}
*/
class Row extends Component {

  render() {
    const RenderRows = ({ data, metaData, styles }) => (
      <div className="table-row" style={styles.gridTableRow}>
        {metaData.headerConfig.map((columnMetaData) => {
          if (columnMetaData.customComponent) {
            const CustomComponent = columnMetaData.customComponent;
            return (
              <RowCell
                isCustomComponent
                styles={styles}
                key={columnMetaData.key}
                cellId={columnMetaData.key}
              >
                <CustomComponent rowData={data} />
              </RowCell>
            );
          }
          return (
            <RowCell
              styles={styles}
              key={columnMetaData.key}
              cellId={columnMetaData.key}
              title={data[columnMetaData.key]}
            >
              {data[columnMetaData.key]}
            </RowCell>
          );
        })}
      </div>
    );
    return (
      <div className="table-body-row">
        <RenderRows
          data={this.props.data}
          metaData={this.props.metaData}
          styles={this.props.styles}
        />
      </div>
    );
  }
}

Row.propTypes = {
  data: PropTypes.object,
  metaData: PropTypes.object,
  styles: PropTypes.object,
};

Row.defaultProps = {
  data: [],
  metaData: {},
  styles: {},
};

export default Row;
