import React, { Component } from 'react';
import { isEmpty } from '../../utils/CommonUtils';
import PropTypes from 'prop-types';

import Pagination from './Pagination';
import Search from './Search';
import '../.././datagrid.css';
import GridExport from './GridExport';

/*
*  The TableDrawer component for the grid which will render - renderPagination, FaArrowLeft, FaArrowRight and Search.
 * It will also handle the onPageDecrement, onPageIncrement and pagination functionality for the grid.
 * @type {class}
*/

class TableDrawer extends Component {
  constructor(props) {
    super(props);
    this.onSort = this.onSort.bind(this);
  }
  onSort(columnId) {
    this.props.onSort(columnId);
  }
  renderSearch() {
    if (this.props.positions.globalSearch) {
      return (
        <Search
          position={this.props.positions}
          metaData={this.props.metaData}
          onSearch={this.props.onSearch}
          handleReRenderButtonClick={this.props.handleReRenderButtonClick}
        />
      );
    }
    return null;
  }
  renderPagination() {
    if (this.props.positions.pagination) {
      return (
        <Pagination
          data={this.props.data}
          onPagination={this.props.onPagination}
          currentPage={this.props.currentPage}
          recordsPerPage={this.props.recordsPerPage}
        />
      );
    }
    return null;
  }

  renderExportButton() {
    if (this.props.positions.exportButton) {
      return (
        <GridExport metaData={this.props.metaData} data={this.props.data} />
      );
    }
    return null;
  }
  dataLength() {
    if (this.props.positions.totalRecords) {
      if (!isEmpty(this.props.gridState.data)) {
        return (
          <div className="table-footer-cell">
            Total Records: {this.props.gridState.data.length}
          </div>);
      } else {
        return (
          <div className="table-footer-cell">
            Total Records: 0
          </div>);
      }

    }
    return null;
  }

  render() {
    return (
      <div className="total-record-row" style={this.props.styles.gridTableRow}>
        <div className="wrapper-pagination-search">
          {this.renderPagination()}
          {this.renderSearch()}
          <div className="grid-export">
            {this.renderExportButton()}
          </div>
          {this.dataLength()}
        </div>
      </div>
    );
  }
}

TableDrawer.propTypes = {
  handleReRenderButtonClick: PropTypes.func.isRequired,
  data: PropTypes.array,
  metaData: PropTypes.object,
  styles: PropTypes.object,
  onPagination: PropTypes.func.isRequired,
  onSort: PropTypes.func.isRequired,
  onSearch: PropTypes.func.isRequired,
  currentPage: PropTypes.number,
  recordsPerPage: PropTypes.number,
  positions: PropTypes.object,
  gridState: PropTypes.object,
};

TableDrawer.defaultProps = {
  data: [],
  metaData: {},
  styles: {},
  currentPage: 0,
  recordsPerPage: 0,
  positions: {},
  gridState: {},
};

export default TableDrawer;
