import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cloneDeep from 'lodash/cloneDeep';
import { getNoOfPages, addUniqueKey } from './utils/CommonUtils';
import './datagrid.css';
import DataGridSection from './components/dataGrid/DataGrid';

/*
 The DataGrid component for the grid which will render - DataGridSection.
 @type {class}
*/
const formattedData = (data, columnsConfig) => {
  const allkeys = columnsConfig.map(columnConfig => columnConfig.key);
  return data.map((dataObj) => {
    const dataObjCopy = cloneDeep(dataObj);
    allkeys.forEach((key) => {
      if (dataObjCopy[key] === undefined) {
        dataObjCopy[key] = '';
      }
    });
    return dataObjCopy;
  });
};

class DataGrid extends Component {
  constructor(props) {
    super(props);
    this.state = {
      data: addUniqueKey(this.props.data),
      metaData: this.props.metaData,
      styles: this.props.styles,
      recordsPerPage: this.props.metaData.recordsPerPage,
      indexOfLastRecord: this.props.metaData.recordsPerPage - 1,
      indexOfFirstRecord: 0,
      noOfPages: getNoOfPages(this.props.data, this.props.metaData.recordsPerPage),
    };
  }
  render() {
    const tempData = formattedData(this.props.data, this.props.metaData.headerConfig);
    return (
      <DataGridSection
        data={tempData}
        metaData={this.props.metaData}
        styles={this.props.styles}
        gridState={this.state}
      />
    );
  }
}

DataGrid.propTypes = {
  data: PropTypes.array,
  metaData: PropTypes.object,
  styles: PropTypes.object,
};

DataGrid.defaultProps = {
  data: [],
  metaData: {},
  styles: {},
};

export default DataGrid;
